pub struct A2AServer {
pub agent_card: AgentCard,
pub registry: AgentCardRegistry,
pub profile_store: ProfileStore,
/* private fields */
}Expand description
A2A server for handling incoming JSON-RPC requests.
This is a protocol server (request router + in-memory task store), not a network server. A shell crate is responsible for exposing it over HTTP/SSE.
Fields
agent_card: AgentCardThis agent’s card.
registry: AgentCardRegistryRegistry of known agents.
profile_store: ProfileStoreProfile store for bearer token authentication.
Implementations
Sourceimpl A2AServer
impl A2AServer
Sourcepub fn handle_request(&self, request: A2ARequest) -> A2AResponse
pub fn handle_request(&self, request: A2ARequest) -> A2AResponse
Handle an incoming JSON-RPC request.
Sourcepub fn handle_request_with_auth(
&self,
request: A2ARequest,
auth_token: Option<&str>,
) -> A2AResponse
pub fn handle_request_with_auth( &self, request: A2ARequest, auth_token: Option<&str>, ) -> A2AResponse
Handle an incoming JSON-RPC request with an optional bearer token.
Sourcepub fn get_task_caller(&self, task_id: &str) -> Option<AgentProfile>
pub fn get_task_caller(&self, task_id: &str) -> Option<AgentProfile>
Get the caller profile for a task (if known).
Sourcepub fn subscribe_events(&self) -> Receiver<A2ATaskEvent>
pub fn subscribe_events(&self) -> Receiver<A2ATaskEvent>
Subscribe to task lifecycle events for streaming adapters.
Sourcepub fn list_tasks(&self) -> Vec<A2ATask>
pub fn list_tasks(&self) -> Vec<A2ATask>
List currently known tasks.
Sourcepub fn update_task_status(
&self,
task_id: &str,
status: TaskStatus,
) -> Result<(), String>
pub fn update_task_status( &self, task_id: &str, status: TaskStatus, ) -> Result<(), String>
Update task status (for internal use).
Sourcepub fn update_task_status_with_reason(
&self,
task_id: &str,
status: TaskStatus,
reason: impl Into<String>,
) -> Result<(), String>
pub fn update_task_status_with_reason( &self, task_id: &str, status: TaskStatus, reason: impl Into<String>, ) -> Result<(), String>
Update task status and message for internal execution bridges.
Sourcepub fn update_task_progress(
&self,
task_id: &str,
progress: RemoteTaskProgress,
) -> Result<(), String>
pub fn update_task_progress( &self, task_id: &str, progress: RemoteTaskProgress, ) -> Result<(), String>
Report in-flight task progress for internal execution bridges.
Sourcepub fn add_message(
&self,
task_id: &str,
message: A2AMessage,
) -> Result<(), String>
pub fn add_message( &self, task_id: &str, message: A2AMessage, ) -> Result<(), String>
Append a message to a task for final result delivery.